@@ -83,6 +83,11 @@
         <source>You don't have permissions to proceed.</source>
         <translation type="unfinished">No tiene permisos para proceder.</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>About</source>
+        <translation type="unfinished">Acerca de</translation>
+    </message>
 </context>
 <context>
     <name>BookWindow</name>
@@ -795,4 +800,17 @@
         <translation type="unfinished">Cerrar</translation>
     </message>
 </context>
+<context>
+    <name>About</name>
+    <message>
+        <location filename="../about.cpp" line="10"/>
+        <source>About FileBox</source>
+        <translation type="unfinished">Acerca de FileBox</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="10"/>
+        <source>File Manager for Maemo 5</source>
+        <translation type="unfinished">Admin de archivos para Maemo 5</translation>
+    </message>
+</context>
 </TS>
